@@ -4,17 +4,23 @@ use warnings;
 
 use Data::Dumper::Compact qw(ddc);
 use Getopt::Long qw(GetOptions);
-use MIDI::Util qw(setup_score midi_format);
+use MIDI::Util qw(setup_score midi_format play_fluidsynth);
 use Music::Chord::Note ();
 use Music::Dice ();
 
 my %opt = (
-    tonic => 'C',
-    scale => 'major',
+    tonic     => 'C',
+    scale     => 'major',
+    octave    => 4,
+    soundfont => $ENV{HOME} . '/Music/soundfont/FluidR3_GM.sf2',
+    midi_file => "$0.mid",
 );
 GetOptions(\%opt,
     'tonic=s',
     'scale=s',
+    'octave=i',
+    'soundfont=s',
+    'midi_file=s',
 );
 
 my $d = Music::Dice->new(
@@ -44,9 +50,11 @@ for (1 .. 4) {
             @tones = split /\s+/, $spec->[1];
         }
         else {
-            @tones = $cn->chord_with_octave($spec->[1], 4);
+            @tones = $cn->chord_with_octave($spec->[1], $opt{octave});
         }
         $score->n($spec->[0], midi_format(@tones))
     }
 }
-$score->write_score("$0.mid");
+
+# $score->write_score($opt{midi_file});
+play_fluidsynth($score, $opt{midi_file}, $opt{soundfont});
